@@ -2,7 +2,7 @@
 
 # DIDIS - Desy ITk Database Interaction Script -- DESY's very own framework for interacting with the ITk Production Database
 # Based on itkdb: https://gitlab.cern.ch/atlas-itk/sw/db/itkdb
-# Created: 2021/11/17, Updated: 2021/11/19
+# Created: 2021/11/17, Updated: 2022/01/24
 # Written by Maximilian Felix Caspar, DESY HH
 
 
@@ -239,6 +239,7 @@ def upload(result: "Results from the test (path to .json file or dict)"):
     except:
         logger.error(f"Unable to upload result to DB, is the format correct?")
 
+
 def testruns(cid: "Component ID",
              returnResults: "Return lookup results (useful if not used from CLI)" = False,
              printJSON: "PrettyPrint the component JSON" = False):
@@ -246,10 +247,11 @@ def testruns(cid: "Component ID",
     try:
         logger.info(f"Looking up tests in CID = {cid}")
         client = itkdb.Client()
-        runs = client.get('listTestRunsByComponent', json={'component' : cid})
+        runs = client.get('listTestRunsByComponent', json={'component': cid})
         results = {}
         for i, testres in enumerate(runs):
-            logger.info(f"Found {testres['testType']['name']} with ID = {testres['id']}")
+            logger.info(
+                f"Found {testres['testType']['name']} with ID = {testres['id']}")
             results[testres['id']] = testres
         if printJSON:
             for k in results:
@@ -262,11 +264,42 @@ def testruns(cid: "Component ID",
             "Are environment variables ITKDB_ACCESS_CODE1 and ITKDB_ACCESS_CODE2 set?")
 
 
+def testfile(file: "Path of the file to upload",
+             testrun: "Test run code",
+             title: "Title of the file" = "",
+             description: "A file description" = "",
+             filetype: "File MIME type (sript can usually guess this)" = None):
+    "Attach a file to a testrun in the DB."
+    try:
+        client = itkdb.Client()
+        if filetype is None:
+            # If you can't be bothered to look up the MIME type,
+            # we'll look it up for you :)
+            filetype = mimetypes.guess_type(file)
+        data = {
+            'testRun': testrun,
+            'title': title,
+            'description': description,
+            'type': 'file',
+            'url': file,
+        }
+        # Get attachment data
+        attachment = {'data': (os.path.basename(
+            file), open(file, 'rb'), filetype)}
+
+        client.post('createTestRunAttachment',
+                    data=data, files=attachment)
+        logger.info(f"Attached file {file} to {testrun}")
+    except:
+        logger.error("Error while trying to get connection to DB")
+        logger.info(
+            "Are environment variables ITKDB_ACCESS_CODE1 and ITKDB_ACCESS_CODE2 set?")
+
 
 def main():
     parser = argh.ArghParser()
     parser.add_commands([authenticate, register, lookup,
-                        attach, tests, stage, skeleton, upload, testruns])
+                        attach, tests, stage, skeleton, upload, testruns, testfile])
     parser.dispatch()
 
 
